@@ -7,8 +7,8 @@ import fire
 
 
 class Regbot:
-  reg_model_path = resource_filename(__name__, 'btcgrad_model.h5') 
-  model_scaler_path = resource_filename(__name__, 'btcgradcaler.gz') 
+  reg_model_path = resource_filename(__name__, 'btc_model.h5') 
+  model_scaler_path = resource_filename(__name__, 'btclogscaler.gz') 
 
 
   def __init__(self,*args):
@@ -23,8 +23,11 @@ class Regbot:
 
 
   @classmethod  
-  def prepareInput(cls,opening,high,low,closing):
-    testdata = np.array([[opening,high,low,closing]])
+  def prepareInput(cls,opening,closing,utcdate):
+    avr = closing/(opening + closing)
+    bvr = opening/(opening + closing)
+    utctime = utcdate.split(' ')[1][1]
+    testdata = np.array([[avr,bvr,utctime]])
     scaler = joblib.load(f'{cls.model_scaler_path}')
     testdata = scaler.transform(testdata)
 
@@ -32,17 +35,17 @@ class Regbot:
 
 
   @classmethod
-  def buySignalGenerator(cls,opening,high,low,closing):
-    scalledInput = cls.prepareInput(opening,high,low,closing)
+  def buySignalGenerator(cls,opening,closing,utcdate):
+    scalledInput = cls.prepareInput(opening,closing,utcdate)
     return np.round(np.clip(cls.loadmodel().predict(scalledInput), 0, 1) > 0)[0].astype(int)
 
 
 
 
 
-def signal(opening,high,low,closing):
+def signal(opening, closing,utcdate):
   try:
-    return Regbot.buySignalGenerator(opening,high,low,closing)
+    return Regbot.buySignalGenerator(opening,closing,utcdate)
   except Exception as e:
     print(e)
 
